@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1701';
+our $VERSION = '0.1702';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -90,11 +90,13 @@ sub parse {
 #        'D##' => 'E',
 #        'F##' => 'G',
 #        'G##' => 'A',
+#        'A##' => 'B',
 #    );
 #    for ( @notes ) {
-#        s/$_/$ss_enharmonics{$_}/
+#        $_ = $ss_enharmonics{$_}
 #            if $ss_enharmonics{$_};
 #    }
+#use Data::Dumper;warn(__PACKAGE__,' ',__LINE__," MARK: ",Dumper\@notes);
 
     # Convert a diminished chord
     $chord =~ s/dim/o/;
@@ -209,6 +211,10 @@ sub parse {
 
     # Append the remaining decorator to the roman representation
     $roman .= $decorator;
+
+    $roman =~ s/bI\b/vii/g;
+    $roman =~ s/bIV\b/iii/g;
+
     print "ROMAN 4: $roman\n" if $self->verbose;
 
     return $roman;
@@ -338,7 +344,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1701
+version 0.1702
 
 =head1 SYNOPSIS
 
